Documentation
¶
Overview ¶
Package sqlite implements the aitm storage interfaces using SQLite.
Index ¶
- type Bots
- func (s *Bots) CreateBotSignature(sig aitm.BotSignature) error
- func (s *Bots) DeleteBotSignature(ja4Hash string) error
- func (s *Bots) DeleteBotTelemetry(sessionID string) error
- func (s *Bots) GetBotTelemetry(sessionID string) ([]*aitm.BotTelemetry, error)
- func (s *Bots) ListBotSignatures() ([]aitm.BotSignature, error)
- func (s *Bots) StoreBotTelemetry(t *aitm.BotTelemetry) error
- type DB
- type Lures
- type Notifications
- type Operators
- func (s *Operators) ConsumeInvite(token string) (*aitm.OperatorInvite, error)
- func (s *Operators) CreateInvite(invite *aitm.OperatorInvite) error
- func (s *Operators) CreateOperator(op *aitm.Operator) error
- func (s *Operators) DeleteOperator(name string) error
- func (s *Operators) ListInvites() ([]*aitm.OperatorInvite, error)
- func (s *Operators) ListOperators() ([]*aitm.Operator, error)
- type Phishlets
- func (s *Phishlets) DeletePhishlet(name string) error
- func (s *Phishlets) GetConfig(name string) (*aitm.PhishletConfig, error)
- func (s *Phishlets) GetPhishlet(name string) (string, error)
- func (s *Phishlets) ListConfigs(filter aitm.PhishletFilter) ([]*aitm.PhishletConfig, error)
- func (s *Phishlets) ListPhishlets() ([]string, error)
- func (s *Phishlets) SavePhishlet(name string, yaml string) error
- func (s *Phishlets) SetConfig(cfg *aitm.PhishletConfig) error
- type Sessions
- func (s *Sessions) CountSessions(f aitm.SessionFilter) (int, error)
- func (s *Sessions) CreateSession(session *aitm.Session) error
- func (s *Sessions) DeleteSession(id string) error
- func (s *Sessions) GetSession(id string) (*aitm.Session, error)
- func (s *Sessions) ListSessions(f aitm.SessionFilter) ([]*aitm.Session, error)
- func (s *Sessions) UpdateSession(session *aitm.Session) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bots ¶
type Bots struct {
// contains filtered or unexported fields
}
Bots implements bot telemetry and signature persistence backed by SQLite.
func NewBotStore ¶
func (*Bots) CreateBotSignature ¶
func (s *Bots) CreateBotSignature(sig aitm.BotSignature) error
func (*Bots) DeleteBotSignature ¶
func (*Bots) DeleteBotTelemetry ¶
func (*Bots) GetBotTelemetry ¶
func (s *Bots) GetBotTelemetry(sessionID string) ([]*aitm.BotTelemetry, error)
func (*Bots) ListBotSignatures ¶
func (s *Bots) ListBotSignatures() ([]aitm.BotSignature, error)
func (*Bots) StoreBotTelemetry ¶
func (s *Bots) StoreBotTelemetry(t *aitm.BotTelemetry) error
type DB ¶
type DB struct {
// contains filtered or unexported fields
}
DB is the shared SQLite connection. Open once; pass to each domain store constructor.
type Lures ¶
type Lures struct {
// contains filtered or unexported fields
}
Lures implements the lureStore interface defined in the aitm package.
func NewLureStore ¶
func (*Lures) DeleteLure ¶
type Notifications ¶
type Notifications struct {
// contains filtered or unexported fields
}
Notifications implements the notificationStore interface defined in the aitm package.
func NewNotificationStore ¶
func NewNotificationStore(db *DB) *Notifications
func (*Notifications) CreateChannel ¶
func (s *Notifications) CreateChannel(ch *aitm.NotificationChannel) error
func (*Notifications) DeleteChannel ¶
func (s *Notifications) DeleteChannel(id string) error
func (*Notifications) GetChannel ¶
func (s *Notifications) GetChannel(id string) (*aitm.NotificationChannel, error)
func (*Notifications) ListChannels ¶
func (s *Notifications) ListChannels() ([]*aitm.NotificationChannel, error)
type Operators ¶ added in v0.2.0
type Operators struct {
// contains filtered or unexported fields
}
Operators implements the operatorStore interface defined in the aitm package.
func NewOperatorStore ¶ added in v0.2.0
func (*Operators) ConsumeInvite ¶ added in v0.2.0
func (s *Operators) ConsumeInvite(token string) (*aitm.OperatorInvite, error)
func (*Operators) CreateInvite ¶ added in v0.2.0
func (s *Operators) CreateInvite(invite *aitm.OperatorInvite) error
func (*Operators) CreateOperator ¶ added in v0.2.0
func (*Operators) DeleteOperator ¶ added in v0.2.0
func (*Operators) ListInvites ¶ added in v0.2.0
func (s *Operators) ListInvites() ([]*aitm.OperatorInvite, error)
type Phishlets ¶
type Phishlets struct {
// contains filtered or unexported fields
}
Phishlets implements the phishletStore interface defined in the aitm package.
func NewPhishletStore ¶
func (*Phishlets) DeletePhishlet ¶
func (*Phishlets) GetConfig ¶ added in v0.3.0
func (s *Phishlets) GetConfig(name string) (*aitm.PhishletConfig, error)
func (*Phishlets) ListConfigs ¶ added in v0.3.0
func (s *Phishlets) ListConfigs(filter aitm.PhishletFilter) ([]*aitm.PhishletConfig, error)
func (*Phishlets) ListPhishlets ¶
func (*Phishlets) SavePhishlet ¶ added in v0.3.0
type Sessions ¶
type Sessions struct {
// contains filtered or unexported fields
}
Sessions implements the sessionStore interface defined in the aitm package.
func (*Sessions) CountSessions ¶
func (s *Sessions) CountSessions(f aitm.SessionFilter) (int, error)
func (*Sessions) DeleteSession ¶
func (*Sessions) ListSessions ¶
Click to show internal directories.
Click to hide internal directories.